Author: brandonwilliams
Date: Thu Sep 16 13:42:16 2010
New Revision: 997748

URL: http://svn.apache.org/viewvc?rev=997748&view=rev
Log:
only attempt to set thread stack size on Linux.  Patch by Peter Schuller, 
reviewed by brandonwilliams for CASSANDRA-1508

Modified:
    cassandra/trunk/conf/cassandra-env.sh

Modified: cassandra/trunk/conf/cassandra-env.sh
URL: 
http://svn.apache.org/viewvc/cassandra/trunk/conf/cassandra-env.sh?rev=997748&r1=997747&r2=997748&view=diff
==============================================================================
--- cassandra/trunk/conf/cassandra-env.sh (original)
+++ cassandra/trunk/conf/cassandra-env.sh Thu Sep 16 13:42:16 2010
@@ -74,10 +74,13 @@ JVM_OPTS="$JVM_OPTS -Xms$MAX_HEAP_SIZE"
 JVM_OPTS="$JVM_OPTS -Xmx$MAX_HEAP_SIZE"
 JVM_OPTS="$JVM_OPTS -XX:+HeapDumpOnOutOfMemoryError" 
 
-# reduce the per-thread stack size to minimize the impact of Thrift
-# thread-per-client.  (Best practice is for client connections to
-# be pooled anyway.)
-JVM_OPTS="$JVM_OPTS -Xss128k" 
+if [ "`uname`" = "Linux" ] ; then
+    # reduce the per-thread stack size to minimize the impact of Thrift
+    # thread-per-client.  (Best practice is for client connections to
+    # be pooled anyway.) Only do so on Linux where it is known to be
+    # supported.
+    JVM_OPTS="$JVM_OPTS -Xss128k"
+fi
 
 # GC tuning options.
 JVM_OPTS="$JVM_OPTS -XX:+UseParNewGC" 


Reply via email to